# netdata-pandas
> A helper library to pull data from netdata api into a pandas dataframe.


## Install

`pip install netdata-pandas`

## Quickstart

Fill me in please! Don't forget code examples:

```python
1+1
```




    2


